export declare type IDynamoKeyConditionParams<T = any> = {
    $eq?: string | number;
    $gt?: string | number;
    $gte?: string | number;
    $lt?: string | number;
    $lte?: string | number;
    $between?: [string | number | Date, string | number | Date];
    $beginsWith?: string;
};
export declare type IDynamoQueryConditionParams<T = any> = IDynamoKeyConditionParams & {
    $in?: string[] | number[];
    $contains?: string;
    $notContains?: string;
    $notEq?: any;
    $exists?: true;
    $notExists?: true;
};
declare type FieldKeyExclude = "";
declare type QueryPartialAllPre<T> = {
    [P in keyof T]: T[P] | IDynamoQueryConditionParams<T>;
};
declare type QueryPartialAll<T> = Pick<QueryPartialAllPre<T>, Exclude<keyof QueryPartialAllPre<T>, FieldKeyExclude>>;
declare type QueryPartialBasicPre<T> = {
    [P in keyof T]: T[P] | IDynamoKeyConditionParams<T>;
};
declare type QueryPartialBasic<T> = Pick<QueryPartialBasicPre<T>, Exclude<keyof QueryPartialBasicPre<T>, FieldKeyExclude>>;
export interface IDynamoPagingResult<T> {
    lastKeyHash?: any;
    mainResult: T;
}
export declare type IDynamoPagingParams = {
    evaluationLimit?: number;
    pageSize?: number;
    lastKeyHash?: any;
    orderDesc?: boolean;
};
export declare type IQueryDefinition<T> = QueryPartialAll<Partial<T>> & {
    $or?: QueryPartialAll<Partial<T>>[];
};
export interface IDynamoQuerySecondaryParamOptions<T> {
    query: IQueryDefinition<T>;
    fields?: (keyof T)[];
    pagingParams?: IDynamoPagingParams;
}
export interface IDynamoQueryParamOptions<T, ISortKeyObjField = any> {
    query?: IQueryDefinition<T>;
    fields?: (keyof T)[];
    partitionSortKeyQuery: {
        partitionKeyEquals: string;
        sortKeyQuery?: QueryPartialBasic<Required<ISortKeyObjField>>;
    };
    pagingParams?: IDynamoPagingParams;
}
export {};
